.. -*- mode: rst -*-

.. include:: changes/names.rst

====
Team
====

This work is made available by a community of people, which
originated from
the :BoA:`Biomarkers of Aging Consortium <>`

.. _core_devs:

Core Team
...............

* `Seth Paulson`_  /  `Biolearn Lead <https://www.linkedin.com/in/seth-paulson-6ba80226/>`_
* `Mahdi Moqri`_  /  `Researcher & BoA Executive <https://www.linkedin.com/in/mahdi-moqri-41432547/>`_
* `Albert Ying`_ / `Harvard Universiy <https://scholar.google.com/citations?user=JS7AdkcAAAAJ&hl=zh-CN>`_
* `Marc Balestreri`_/ `Software Engineer <https://www.linkedin.com/in/marcbal/>`_

Other contributors
..................

* `Martin Perez-Guevara`_  /  `Machine Learning Engineer <https://www.linkedin.com/in/martin-perez-guevara/>`_
* `Chancen Law`_/ `Harvard university <https://www.linkedin.com/in/chancenlaw/>`_
* `Alec Eames`_ / `Harvard Universiy <https://www.linkedin.com/in/alec-eames-589a3917a/>`_
* `Dayoon Kwon`_ /  `University of California <https://scholar.google.com/citations?user=5L9djqsAAAAJ&hl=en>`_
* `Mehrnoosh Emamifar`_/ `Northeastern university <https://www.linkedin.com/in/mehrnoosh-emamifar/>`_
* `Nureldin Mohamed`_/ `Harvard university <https://www.linkedin.com/in/nureldin-m-19738625b/>`_
* `Yasamin Jodat`_/ `Gingko Bioworks <https://www.linkedin.com/in/yasamin-jodat/>`_
* `Aneesh Mazumder`_/ `Harvard university <https://www.linkedin.com/in/aneesh-mazumder/>`_
* `Antonino Libarnes`_/ `Harvard university <https://www.linkedin.com/in/anjolib/>`_
* `Alexis Musaelyan-Blackmon`_/ `Harvard university <https://www.linkedin.com/in/alexis-musaelyan-blackmon/>`_


Partner Organizations
.....................
* `AI4Life Institute`_

Special thanks to scientific and executive members of the :BoA:`Biomarkers of Aging Consortium <>`
